Package: pkglite
Title: Compact Package Representations
Version: 0.2.4
Authors@R: c(
    person("Nan", "Xiao", email = "nan.xiao1@merck.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-0250-5673")),
    person("Yilong", "Zhang", role = "aut"),
    person("Keaven", "Anderson", email = "keaven_anderson@merck.com", role = "aut"),
    person("Amin", "Shirazi", role = "ctb"),
    person("Jeff", "Cheng", role = "ctb"),
    person("Danfeng", "Fu", role = "ctb"),
    person("Merck & Co., Inc., Rahway, NJ, USA and its affiliates", role = "cph")
    )
Description: A tool, grammar, and standard to represent and exchange
    R package source code as text files. Converts one or more source
    packages to a text file and restores the package structures from the file.
License: GPL-3
URL: https://merck.github.io/pkglite/, https://github.com/Merck/pkglite
BugReports: https://github.com/Merck/pkglite/issues
Encoding: UTF-8
VignetteBuilder: knitr
Depends: R (>= 3.5.0)
Imports: crayon, magrittr, remotes
Suggests: covr, knitr, rmarkdown, testthat
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
Author: Nan Xiao [aut, cre] (<https://orcid.org/0000-0002-0250-5673>),
  Yilong Zhang [aut],
  Keaven Anderson [aut],
  Amin Shirazi [ctb],
  Jeff Cheng [ctb],
  Danfeng Fu [ctb],
  Merck & Co., Inc., Rahway, NJ, USA and its affiliates [cph]
Maintainer: Nan Xiao <nan.xiao1@merck.com>
Built: R 4.4.2; ; 2024-12-05 19:38:51 UTC; unix
